@@ -282,14 +282,6 @@ RMaxima <- R6::R6Class("RMaxima",
           private$display <- display
           private$port <- port
     },
-    finalize = function() {
-      # in here no more method calls are possible
-      # suppressMessages(self$stop())
-      if(private$running) { 
-        private$sendCommand("quit();")
-        close(private$maximaSocket)
-      }
-    },
     isInstalled = function() {
       if(!nchar(private$maximaPath) || 
          length(grep(pattern = "maxima", 
@@ -421,6 +413,9 @@ RMaxima <- R6::R6Class("RMaxima",
     getLastPromptID = function() {
       private$lastPromptID
     },
+    getCurrentInputLabel = function() {
+      private$reply$getInputLabel()
+    },
     getLastInputLabel = function() {
       private$lastInputLabel
     },
@@ -429,7 +424,7 @@ RMaxima <- R6::R6Class("RMaxima",
     },
     loadModule = function(module) {
       if(length(module) > 0 && nchar(module))
-        self$get(paste0("load(\"", module, "\")$")) 
+        self$get(paste0("load(", module, ")$")) 
     },
     get_stuck = function(command) {
       # executes command without advancing reference labels
@@ -498,7 +493,7 @@ RMaxima <- R6::R6Class("RMaxima",
 
         private$parseStartUp()
         private$reply <- Reply$new(private$maximaSocket)
-        private$lastInputLabel <- private$reply$getInputLabel
+        private$lastInputLabel <- private$reply$getInputLabel()
         private$running <- TRUE
 
       },
@@ -553,6 +548,14 @@ RMaxima <- R6::R6Class("RMaxima",
                                          " ",  private$preload))
           }
         }
+      },
+      finalize = function() {
+        # in here no more method calls are possible
+        # suppressMessages(self$stop())
+        if(private$running) { 
+          private$sendCommand("quit();")
+          close(private$maximaSocket)
+        }
       }
     )
 )
